@@ -1,9 +1,9 @@
-/* $Id: filter.cc,v 1.5 2000/02/20 21:45:32 bergo Exp $ */
+/* $Id: filter.cc,v 1.7 2002/03/10 18:37:09 bergo Exp $ */
 
 /*
 
     GPS - Graphical Process Statistics
-    Copyright (C) 1999-2000 Felipe Paulo Guazzi Bergo
+    Copyright (C) 1999-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -48,7 +48,7 @@ void clear_filter (GtkWidget * widget, gpointer data) {
 void set_filter_dialog (GtkWidget * widget, gpointer data) {
   GtkWidget *dlg,*v1,*h1;
   GtkWidget *b[10],*h2,*h3,*h4,*l3,*s1,*ok,*can,*h5;
-  static GtkWidget *l1,*l2,*e1,*il;
+  static GtkWidget *l1,*l2,*e1;
   static int acoxambre[10]={0,1,2,3,4,5,6,7,8,9};
   int i,j;
   char buffer[5][64];
@@ -123,18 +123,21 @@ void set_filter_dialog (GtkWidget * widget, gpointer data) {
   s1=gtk_hseparator_new();
   gtk_box_pack_start(GTK_BOX(v1),s1,FALSE,TRUE,4);
 
-  h5=gtk_hbox_new(TRUE,4);
-  il=gtk_label_new(" ");
+  h5=gtk_hbutton_box_new();
+  gtk_button_box_set_layout(GTK_BUTTON_BOX(h5), GTK_BUTTONBOX_END);
+  gtk_button_box_set_spacing(GTK_BUTTON_BOX(h5), 5);
+
   ok=gtk_button_new_with_label("Ok");
+  GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
   can=gtk_button_new_with_label("Cancel");
+  GTK_WIDGET_SET_FLAGS(can,GTK_CAN_DEFAULT);
 
-  gtk_box_pack_start(GTK_BOX(v1),h5,FALSE,TRUE,2);
+  gtk_box_pack_start(GTK_BOX(v1),h5,FALSE,FALSE,6);
+  gtk_box_pack_start(GTK_BOX(h5),ok,TRUE,TRUE,0);
+  gtk_box_pack_start(GTK_BOX(h5),can,TRUE,TRUE,0);
 
-  gtk_box_pack_start(GTK_BOX(h5),il,FALSE,TRUE,4);
-  gtk_box_pack_start(GTK_BOX(h5),ok,FALSE,TRUE,4);
-  gtk_box_pack_start(GTK_BOX(h5),can,FALSE,TRUE,4);
+  gtk_widget_grab_default(ok);
 
-  gtk_widget_show(il);
   gtk_widget_show(ok);
   gtk_widget_show(can);
   gtk_widget_show(h5);
@@ -173,7 +176,8 @@ void filter_set_field(GtkWidget *gw,gpointer data) {
   int *k;
   static char buffer[64];
   k=(int *)data;
-  sprintf(buffer,"Field to filter: %s",col_title[*k]);
+  snprintf(buffer,64,"Field to filter: %s",col_title[*k]);
+  buffer[63]=0;
   gtk_label_set_text(GTK_LABEL(lf1),buffer);
   fi_stru.field=*k;
 }
@@ -236,10 +240,11 @@ void filter_set_ok(GtkWidget *gw,gpointer data) {
   gtk_grab_remove(filter_dlg);
   gtk_widget_destroy(filter_dlg);
 
-  sprintf(buffer,"Filter: %s %s %s",
+  snprintf(buffer,256,"Filter: %s %s %s",
 	  col_title[fi_work.field],
 	  opfilter[fi_work.cmp+1],
 	  fi_work.value);
+  buffer[255]=0;
   gtk_label_set_text(GTK_LABEL(status_label[0]),buffer);
 
   refresh();
