@@ -5,7 +5,7 @@
 .\" for conditions under which this file may be redistributed."
 .\" THIS IS FILE WILL GO THORUGH A C PREPROCESSOR AND THE OUTPUT"
 .\" MUST BE A VALID MAN PAGE. BE CAREFUL."
-.TH GPS 1x "22 Feb 2001" CURRENT_OS "User Manuals"
+.TH GPS 1x "March 2002" CURRENT_OS "User Manuals"
 .\"" /*
 .SH NAME
 gps \- graphical tool to report process status
@@ -19,8 +19,13 @@ Extended Kill Mode (EKM) syntax:
 gps k<\fBn\fR|\fBu\fR|\fBg\fR|\fBe\fR|\fBs\fR><\fBq\fR|\fBv\fR|\fBh\fR>[<\fBi\fR|\fBo\fR|\fBb\fR>]
     [-\fBsignal\fR] \fBmatch-text\fR [\fBmatch-text\fR ...]
 
+Quickbar Mode syntax:
+
+gps -qb [\fBtop\fR | \fBbottom\fR] [\fBleft\fR | \fBcenter\fR | \fBright\fR]
+        [\fB-w\fR \fIwidth\fR] [\fB-r\fR]
+
 .SH DESCRIPTION
-This man page documents version 0.9.4 of \fBgps\fR on the
+This man page documents version 1.0.1 of \fBgps\fR on the
 .\"" */
 CURRENT_OS
 .\"" /*
@@ -108,6 +113,9 @@ Use the top poller instead of the native one. The top poller provides
 much less information about processes, and is intended for use only
 in platforms where a native poller is not available. If the piped
 top poller isn't compiled in gps's binary, this option has no effect.
+.IP -qb
+Run in quickbar mode (no process list, just bar graphs), see the
+\fBQuickbar Mode\fR section for mode-specific parameters.
 .IP -sa
 sets sorting direction to ascending (lesser values on top). This is
 already the default if neither -sa nor -sd are specified.
@@ -242,13 +250,6 @@ gps kuqo ricbit | gps keqb snes9x | gps ksvi -TERM FF5.SMC
 gps ksq -KILL netscape
 
 
-However, \fBgps\fR is not perfect. For example,
-.br
-gps ksq -KILL solaris
-
-will not make your SPARC go faster, you must still grab a
-SPARC Linux CD and trash Solaris by hand.
-
 Note on pipe modes: the first process in the pipe sequence must
 be in \fBo\fR mode, all processes but first and last must be in
 \fBb\fR mode, and the last process must be in \fBi\fR mode.
@@ -256,6 +257,36 @@ be in \fBo\fR mode, all processes but first and last must be in
 Note on self-mutilation: \fBgps\fR will not kill \fBgps\fR
 processes in EKM.
 
+.SH "QUICKBAR MODE"
+
+The \fB-qb\fR command-line switch runs gPS in quickbar mode, where
+gPS is only a tiny window with bar graphs for CPU, Memory and
+Swap usage. 
+Clicking on the graph window switches between the bar graph and
+histories for each of the resources measured.
+There are some command-line parameters specific to this mode:
+
+.IP top
+vertical alignment, places the graph window at the top of the screen.
+.IP bottom
+vertical alignment, places the graph window at the bottom of the
+screen (default).
+.IP left
+horizontal alignment, places the graph window at the left of the
+screen.
+.IP center
+horizontal alignment, places the graph window horizontally centered
+(default).
+.IP right
+horizontal alignment, places the graph window at the right of the
+screen.
+.IP "-w \fIwidth\fR"
+specifies the width of the window, in pixels. If not specified, defaults to
+256 pixels. Maximum value is 1024.
+.IP -r
+makes the graph window be a regular window (with decorations) instead
+of a topmost popup.
+
 .SH "FIELD DESCRIPTIONS"
 .TP 0.8i
 .B "PID "
@@ -536,6 +567,8 @@ piped top poller.
 FreeBSD: FreeBSD's process 0 makes a little mess with the
 tree view. The piped top poller won't work with FreeBSD's top,
 but as there is a native poller for FreeBSD, you don't need it.
+Also, GTK+ 1.2.9 won't allow GTK setuid-root applications, so
+you won't (probably) be able to run gPS+FreeBSD+GTK>=1.2.9.
 
 \fBLinux\fR: none that I know of.
 
@@ -552,11 +585,11 @@ package the default prefix is \fI/usr\fR.
 
 .IR ~/.gpsrc
 .br
-.IR /usr/local/doc/gps-0.9.4/README
+.IR /usr/local/doc/gps-1.0.1/README
 .br
-.IR /usr/local/doc/gps-0.9.4/INSTALL
+.IR /usr/local/doc/gps-1.0.1/INSTALL
 .br
-.IR /usr/local/doc/gps-0.9.4/COPYING
+.IR /usr/local/doc/gps-1.0.1/COPYING
 .br
 .IR /usr/local/share/icons/xray-tux.xpm
 .br
@@ -567,7 +600,7 @@ was written by Felipe Bergo <bergo@seul.org>, with contributions
 from Beat Christen (Network watch ideas, rtop) <spiff@seul.org> 
 
 .SH "WEB SITE"
-http://www.gps.seul.org
+http://gps.seul.org
 
 .SH "SEE ALSO"
 \fBproc\fR(5), \fBsignal\fR(7), \fBps\fR(1), \fBtop\fR(1), \fBrenice\fR(8), \fBkill\fR(1), \fBrpm\fR(8), \fBrgpsp\fR(1)
