@@ -1,4 +1,4 @@
-/* $Id: gps.h,v 1.7 2000/08/08 01:07:20 bergo Exp $ */
+/* $Id: gps.h,v 1.9 2002/04/28 19:33:21 bergo Exp $ */
 
 #ifndef GPS_GPS_H
 #define GPS_GPS_H
@@ -66,6 +66,7 @@ void deal_with_kill(gint sig);
 void PosixKill(GtkWidget *widget,gpointer data);
 
 void show_details(GtkWidget *a,gpointer b);
+void watch_process(GtkWidget *a, gpointer b);
 int which_number(char *s);
 gboolean userkey(GtkWidget *widget, GdkEventKey *gek,gpointer data);
 void pre_sort();
@@ -102,4 +103,6 @@ void nethalt_click(GtkWidget *widget,gpointer data);
 void init_default_colors();
 void init_low_depth_colors();
 
+void pdestroy (GtkWidget * widget, gpointer data);
+
 #endif
