@@ -1,9 +1,9 @@
-/* $Id: history.cc,v 1.12 2001/02/23 13:12:53 bergo Exp $ */
+/* $Id: history.cc,v 1.15 2002/03/10 18:37:09 bergo Exp $ */
 
 /*
 
     GPS - Graphical Process Statistics
-    Copyright (C) 1999-2000 Felipe Paulo Guazzi Bergo
+    Copyright (C) 1999-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -96,7 +96,8 @@ void pop_history(GtkWidget *widget, gpointer data) {
   gtk_widget_realize(hdlg);
   gtk_window_set_policy(GTK_WINDOW(hdlg),TRUE,TRUE,TRUE);
   gethostname(bu,256);
-  sprintf(title,"gPS: CPU and Memory (%s)",bu);
+  snprintf(title,512,"gPS: CPU and Memory (%s)",bu);
+  title[511]=0;
   gtk_window_set_title(GTK_WINDOW(hdlg),title);
   gtk_container_set_border_width(GTK_CONTAINER(hdlg),4);
 
@@ -116,7 +117,8 @@ void pop_history(GtkWidget *widget, gpointer data) {
 
     gtk_box_pack_start(GTK_BOX(bh),tb,FALSE,TRUE,2);
     
-    sprintf(bf,"%s (local)",this_host);
+    snprintf(bf,256,"%s (local)",this_host);
+    bf[255]=0;
     lcol[0]=bf;
     gtk_clist_append(GTK_CLIST(tb),(gchar**)lcol);
 
@@ -128,7 +130,7 @@ void pop_history(GtkWidget *widget, gpointer data) {
       gtk_clist_append(GTK_CLIST(tb),(gchar**)lcol);
     }
 
-    sprintf(bf,"All together");
+    strcpy(bf,"All together");
     lcol[0]=bf;
     gtk_clist_append(GTK_CLIST(tb),(gchar**)lcol);
 
@@ -149,17 +151,23 @@ void pop_history(GtkWidget *widget, gpointer data) {
   hs=gtk_hseparator_new();
   gtk_box_pack_start(GTK_BOX(v1),hs,FALSE,FALSE,4);
 
-  h1=gtk_hbox_new(FALSE,2);
-  gtk_box_pack_start(GTK_BOX(v1),h1,FALSE,TRUE,2);
+  h1=gtk_hbutton_box_new();
+  gtk_button_box_set_layout(GTK_BUTTON_BOX(h1), GTK_BUTTONBOX_END);
+  gtk_button_box_set_spacing(GTK_BUTTON_BOX(h1), 5);
 
-  dis=gtk_button_new_with_label("   Dismiss   ");
-  gtk_box_pack_end(GTK_BOX(h1),dis,FALSE,FALSE,2);
+  gtk_box_pack_start(GTK_BOX(v1),h1,FALSE,FALSE,6);
+
+  dis=gtk_button_new_with_label("Dismiss");
+  GTK_WIDGET_SET_FLAGS(dis,GTK_CAN_DEFAULT);
+  gtk_box_pack_start(GTK_BOX(h1),dis,TRUE,TRUE,0);
 
   gtk_signal_connect(GTK_OBJECT(dis),"clicked",
 		     GTK_SIGNAL_FUNC(close_history),NULL);
   gtk_signal_connect (GTK_OBJECT (hdlg), "destroy",
 		      GTK_SIGNAL_FUNC (destroy_history), NULL);
 
+  gtk_widget_grab_default(dis);
+
   gtk_widget_show(v1);
   gtk_widget_show(h1);
   gtk_widget_show(hs);
@@ -1146,7 +1154,7 @@ void *thread_history_poller(void *p) {
 
 gint refresh_history(gpointer data) {
   static int round=0;
-  long pv[6];
+  unsigned long pv[6];
   int i;
   char c[256],b[256];
 
@@ -1171,7 +1179,7 @@ gint refresh_history(gpointer data) {
   
   if (host_slot<0) {
     for(i=0;i<6;i++)
-      pv[i]=0L;
+      pv[i]=0;
     for(i=0;i<history_watch_count;i++) {
       pv[0]+=(history[i]->sip->memory_used>>10);
       pv[1]+=(history[i]->sip->memory_free>>10);
@@ -1193,18 +1201,28 @@ gint refresh_history(gpointer data) {
   }
   for(i=0;i<6;i++) pv[i]>>=10;
   
-  sprintf(b,"%lu %s",pv[0],c);
+  snprintf(b,256,"%lu %s",pv[0],c);
+  b[255]=0;
   gtk_label_set_text(GTK_LABEL(ml[5]),b);
-  sprintf(b,"%lu %s",pv[1],c);
+
+  snprintf(b,256,"%lu %s",pv[1],c);
+  b[255]=0;
   gtk_label_set_text(GTK_LABEL(ml[6]),b);
-  sprintf(b,"%lu %s",pv[2],c);
+
+  snprintf(b,256,"%lu %s",pv[2],c);
+  b[255]=0;
   gtk_label_set_text(GTK_LABEL(ml[7]),b);
   
-  sprintf(b,"%lu %s",pv[3],c);
+  snprintf(b,256,"%lu %s",pv[3],c);
+  b[255]=0;
   gtk_label_set_text(GTK_LABEL(ml[9]),b);
-  sprintf(b,"%lu %s",pv[4],c);
+
+  snprintf(b,256,"%lu %s",pv[4],c);
+  b[255]=0;
   gtk_label_set_text(GTK_LABEL(ml[10]),b);
-  sprintf(b,"%lu %s",pv[5],c);
+
+  snprintf(b,256,"%lu %s",pv[5],c);
+  b[255]=0;
   gtk_label_set_text(GTK_LABEL(ml[11]),b);
 
   return TRUE;
