@@ -1,4 +1,4 @@
-/* $Id: renice.cc,v 1.6 2000/02/20 21:45:36 bergo Exp $ */
+/* $Id: renice.cc,v 1.7 2001/04/17 04:11:54 bergo Exp $ */
 
 /*
 
@@ -46,7 +46,7 @@ GtkWidget *nicedlg;
 
 void renice_dialog(GtkWidget * widget, gpointer data) {
   GtkWidget *dlg;
-  GtkWidget *v1,*h1,*ok,*can,*h2,*l1,*h3,*pp,*hs,*est;
+  GtkWidget *v1,*h1,*ok,*can,*h2,*l1,*h3,*pp,*hs;
   static GtkWidget *sb;
   GtkObject *ad;
   int n,u;
@@ -114,21 +114,24 @@ void renice_dialog(GtkWidget * widget, gpointer data) {
   hs=gtk_hseparator_new();
   gtk_box_pack_start(GTK_BOX(v1),hs,FALSE,TRUE,4);
 
-  h2=gtk_hbox_new(TRUE,4);
-  ok=gtk_button_new_with_label(" Ok ");
-  can=gtk_button_new_with_label(" Cancel ");
+  h2=gtk_hbutton_box_new();
+  gtk_button_box_set_layout(GTK_BUTTON_BOX(h2), GTK_BUTTONBOX_END);
+  gtk_button_box_set_spacing(GTK_BUTTON_BOX(h2), 5);
 
-  est=gtk_label_new(" ");
+  ok=gtk_button_new_with_label("Ok");
+  GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
+  can=gtk_button_new_with_label("Cancel");
+  GTK_WIDGET_SET_FLAGS(can,GTK_CAN_DEFAULT);
 
-  gtk_box_pack_start(GTK_BOX(v1),h2,FALSE,TRUE,2);
+  gtk_box_pack_start(GTK_BOX(v1),h2,FALSE,FALSE,6);
 
-  gtk_box_pack_start(GTK_BOX(h2),est,TRUE,TRUE,2);
-  gtk_box_pack_start(GTK_BOX(h2),ok,FALSE,TRUE,4);
-  gtk_box_pack_start(GTK_BOX(h2),can,FALSE,TRUE,4);
+  gtk_box_pack_start(GTK_BOX(h2),ok,TRUE,TRUE,0);
+  gtk_box_pack_start(GTK_BOX(h2),can,TRUE,TRUE,0);
+
+  gtk_widget_grab_default(ok);
 
   gtk_widget_show(ok);
   gtk_widget_show(can);
-  gtk_widget_show(est);
   gtk_widget_show(hs);
   gtk_widget_show(h2);
   gtk_widget_show(sb);
