@@ -1,9 +1,9 @@
-/* $Id: treeview.cc,v 1.8 2001/02/23 13:12:54 bergo Exp $ */
+/* $Id: treeview.cc,v 1.10 2002/03/10 18:37:10 bergo Exp $ */
 
 /*
 
     GPS - Graphical Process Statistics
-    Copyright (C) 1999-2000 Felipe Paulo Guazzi Bergo
+    Copyright (C) 1999-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -77,7 +77,8 @@ void pop_treeview(GtkWidget *gw,gpointer data) {
   gtk_widget_realize(twnd);
   gtk_window_set_policy(GTK_WINDOW(twnd),TRUE,TRUE,TRUE);
   gethostname(bu,256);
-  sprintf(title,"gPS: Process Tree (%s)",bu);
+  snprintf(title,512,"gPS: Process Tree (%s)",bu);
+  title[511]=0;
   gtk_window_set_title(GTK_WINDOW(twnd),title);
   gtk_container_set_border_width(GTK_CONTAINER(twnd),0);
 
@@ -98,7 +99,8 @@ void pop_treeview(GtkWidget *gw,gpointer data) {
   for(j=0;j<3;j++)
     msub[j]=gtk_menu_new();
   for(i=0;i<POSIXSIG;i++) {
-    sprintf(bu,"%s (%d)",posixnames[i],posixvalues[i]);
+    snprintf(bu,256,"%s (%d)",posixnames[i],posixvalues[i]);
+    bu[255]=0;
     for(j=0;j<3;j++) {
       mti=gtk_menu_item_new_with_label(bu);
       gtk_menu_append(GTK_MENU(msub[j]),mti);
@@ -185,8 +187,12 @@ void pop_treeview(GtkWidget *gw,gpointer data) {
   gtk_box_pack_start(GTK_BOX(vbb),rb,FALSE,TRUE,4);
 
   db=gtk_button_new_with_label("Dismiss");
+  GTK_WIDGET_SET_FLAGS(db,GTK_CAN_DEFAULT);
+
   gtk_box_pack_end(GTK_BOX(vbb),db,FALSE,TRUE,4);
 
+  gtk_widget_grab_default(db);
+
   gtk_widget_show(db);
   gtk_widget_show(ea);
   gtk_widget_show(ca);
@@ -509,8 +515,9 @@ void ProcessLeaf::compose_item() {
 }
 
 char * ProcessLeaf::get_tree_label() {
-  sprintf(local_buffer,"%d %s [%s]",
+  snprintf(local_buffer,512,"%d %s [%s]",
 	  pid,process_title,owner);
+  local_buffer[511]=0;
   return(local_buffer);
 }
 
@@ -701,7 +708,8 @@ void signal_it_friendly(int pid,int zignal) {
   default:
     emsg=ERR_BAD_MAN_PAGES;
   }
-  sprintf(zbuf,"Cannot send signal to PID %d",pid);
+  snprintf(zbuf,256,"Cannot send signal to PID %d",pid);
+  zbuf[255]=0;
   message_box(GTK_WINDOW(twnd),
 	      emsg,
 	      zbuf,
